pub fn schema_from_point_cloud(
schema: &PointSchema,
) -> Result<(Format, PointSchema), IoError>Expand description
Selects a LAS point format for writing the given cloud schema.
pub fn schema_from_point_cloud(
schema: &PointSchema,
) -> Result<(Format, PointSchema), IoError>Selects a LAS point format for writing the given cloud schema.