pub struct LasChunkSink<W: Write + Seek + Send + Sync + 'static> { /* private fields */ }Expand description
Sequential LAS/LAZ sink that writes each leased chunk immediately.
Implementations
Sourceimpl<W: Write + Seek + Send + Sync + 'static> LasChunkSink<W>
impl<W: Write + Seek + Send + Sync + 'static> LasChunkSink<W>
Sourcepub fn new(
writer: W,
schema: SchemaDescriptor,
expected_points: u64,
format: LasWriteFormat,
) -> Result<Self, IoError>
pub fn new( writer: W, schema: SchemaDescriptor, expected_points: u64, format: LasWriteFormat, ) -> Result<Self, IoError>
Creates a LAS/LAZ sink over a seekable writer.
Sourcepub fn new_open_ended(
writer: W,
schema: SchemaDescriptor,
format: LasWriteFormat,
) -> Result<Self, IoError>
pub fn new_open_ended( writer: W, schema: SchemaDescriptor, format: LasWriteFormat, ) -> Result<Self, IoError>
Creates a LAS/LAZ sink whose final point count is not known up front.
The seekable LAS writer patches the header when Self::finish closes it.
Sourceimpl LasChunkSink<BufWriter<File>>
impl LasChunkSink<BufWriter<File>>
Sourcepub fn create(
path: impl AsRef<Path>,
schema: SchemaDescriptor,
expected_points: u64,
format: LasWriteFormat,
) -> Result<Self, IoError>
pub fn create( path: impl AsRef<Path>, schema: SchemaDescriptor, expected_points: u64, format: LasWriteFormat, ) -> Result<Self, IoError>
Creates a local LAS/LAZ file sink.
Sourcepub fn create_open_ended(
path: impl AsRef<Path>,
schema: SchemaDescriptor,
format: LasWriteFormat,
) -> Result<Self, IoError>
pub fn create_open_ended( path: impl AsRef<Path>, schema: SchemaDescriptor, format: LasWriteFormat, ) -> Result<Self, IoError>
Creates a local LAS/LAZ sink whose final point count is not known up front.